@@ -2,8 +2,9 @@
 #'
 #' @export
 #' @param id the taxon identifier code
-#' @param key Your Tropicos API key; loads from .Rprofile.
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @param key Your Tropicos API key; See \code{\link{taxize-authentication}} 
+#' for help on authentication
+#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}}
 #' @return A data.frame.
 #' @examples \dontrun{
 #' tp_summary(id = 25509881)
@@ -13,15 +14,22 @@
 
 tp_summary <- function(id, key = NULL, ...) {
   url <- sprintf('http://services.tropicos.org/Name/%s', id)
-	key <- getkey(key, "tropicosApiKey")
+	key <- getkey(key, "TROPICOS_KEY")
 
   args <- tc(list(apikey = key, format = 'json'))
-  tmp <- GET(url, query = args, ...)
-  stop_for_status(tmp)
-  tmp2 <- con_utf8(tmp)
-  res <- jsonlite::fromJSON(tmp2, FALSE)
+  tt <- tp_GET(url, args, ...)
+  res <- jsonlite::fromJSON(tt, FALSE)
   typespec <- data.frame(res$TypeSpecimens, stringsAsFactors = FALSE)
   df <- data.frame(res[!names(res) %in% "TypeSpecimens"], stringsAsFactors = FALSE)
   if (NROW(typespec) > 0) df <- cbind(df, typespec)
-  setNames(df, tolower(names(df)))
+  stats::setNames(df, tolower(names(df)))
+}
+
+tp_GET <- function(url, query, raise = TRUE, ...) {
+  cli <- crul::HttpClient$new(url = url, opts = list(...),
+    headers = list(`User-Agent` = taxize_ua(), `X-User-Agent` = taxize_ua()))
+  res <- cli$get(query = query)
+  if (!raise) return(res)
+  res$raise_for_status()
+  res$parse("UTF-8")
 }
